<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class BeneficioRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    /**
     * @return array|false
     */
    public function getBeneficio(
        int $nrOrg,
        int $nrBeneficio
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                VAB_BENEFICIOM BM
                JOIN
                VAB_BENEFICIOH BH ON
                    BH.NRBENEFICIOM = BM.NRBENEFICIOM AND
                    BH.NRORG = BM.NRORG AND
                    BH.DTMESCOMPETENC = (
                        SELECT
                            MAX(DTMESCOMPETENC)
                        FROM
                            VAB_BENEFICIOH BH1
                        WHERE
                            BH1.NRORG = BM.NRORG AND
                            BH1.NRBENEFICIOM = BM.NRBENEFICIOM
                    )
            WHERE
                BM.NRORG = :P_NRORG AND
                BM.NRBENEFICIOM = :P_NRBENEFICIOM
SQL;

        $params = [
            'P_NRORG'           => $nrOrg,
            'P_NRBENEFICIOM'    => $nrBeneficio,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        return $result;
    }

    public function setBeneficiario(
        array $params
    ): void {
        $sql = <<<SQL
            INSERT INTO VAB_BENEFICIARIO (
                NRORG,                  NRBENEFICIARIO,         NRBENEFICIOM,
                NRVINCULOM,             NRPESSOA,               NREVENTOM,
                NRINTEGTRANSPM,         NRVALORREFERENCIAM,     NRVINCEVENTO,
                DTINSCBENEFICIARIO,     NRINSCBENEFICIARIO,     DTCANCBENEFICIARIO,
                QTBENEFICIO,            VRBENEFICIO,            IDTPBENEFICIARIO,
                IDVALORDIFEBENEF,       DSOBSBENEFICIARIO,      IDATIVO,
                NRORGINCLUSAO,          DTINCLUSAO,             CDOPERINCLUSAO,
                NRORGULTATU,            DTULTATU,               CDOPERULTATU,
                SUBSIDIO100,            VRPERCSUBSIDIO
            )
            VALUES (
                :NRORG,                 :NRBENEFICIARIO,        :NRBENEFICIOM,
                :NRVINCULOM,            :NRPESSOA,              :NREVENTOM,
                :NRINTEGTRANSPM,        :NRVALORREFERENCIAM,    :NRVINCEVENTO,
                :DTINSCBENEFICIARIO,    :NRINSCBENEFICIARIO,    :DTCANCBENEFICIARIO,
                :QTBENEFICIO,           :VRBENEFICIO,           :IDTPBENEFICIARIO,
                :IDVALORDIFEBENEF,      :DSOBSBENEFICIARIO,     :IDATIVO,
                :NRORGINCLUSAO,         :DTINCLUSAO,            :CDOPERINCLUSAO,
                :NRORGULTATU,           :DTULTATU,              :CDOPERULTATU,
                :SUBSIDIO100,           :VRPERCSUBSIDIO
            )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}